==> nextcloud-26.0.13.tar.bz2: nextcloud/apps/circles/l10n/es_GT.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Shared to Circles" : "Compartido a Círculos",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Password protected" : "Protegido con contraseña",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Files" : "Archivo",
    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Circles" : "Círculos",
    "Circles' files" : "Archivos de los círculos",
    "Select circles to filter by" : "Seleccionar los círculos a filtrar",
    "No circles found" : "No se encontraron círculos",
    "Please select circles to filter by" : "Por favor selecciona los círculos a filtrar",
    "No files found for the selected circles" : "No se encontraron archivos para los círculos seleccionados",
    "You created the circle {circle}" : "Creaste el círculo {circle}",
    "{author} created the circle {circle}" : "{author} creó el círculo {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>Círculo</strong> que estés moderando",
    "Circle not found" : "Círculo no encontrado",
    "Federated link not found" : "No se encontró la liga",
    "The circle is not federated" : "El círculo no es federado",
    "You cannot join this circle" : "No puedes unirte a este cículo",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
    "This member is not an admin of the circle" : "Este miembro no es un administador del círculo",
    "This group does not exist" : "Este grupo no existe",
    "This group is already linked to the circle" : "Este grupo ya ha sido ligado a este círculo",
    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
    "Group cannot be set as owner of a circle" : "Un Grupo no puede ser establecido como dueño de un círculo",
    "now" : "ahora",
    "Email format is not valid" : "El formato de la dirección de correo electrónico no es válido",
    "This contact is not available" : "Este contacto no está disponible"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.13.tar.bz2: nextcloud/apps/circles/l10n/es_GT.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Password protected" : "Protegido con contraseña",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Files" : "Archivo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "Open %s" : "Abierto %s",
    "Try again" : "Reintentar",
    "Loading…" : "Cargando",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Shared to Circles" : "Compartido a Círculos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
